# Contributing to mepo

Contributing code to mepo should be done via a Pull Request to this repository.

## Contributor License Agreement (CLA)

All external developers contributing to GEOS-ESM projects must complete a [Contributor License
Agreement](https://github.com/GEOS-ESM/cla).

NOTE: Internal NASA contributors associated with GEOS, including contractors,
are covered by other agreements and do not need to sign a CLA.

## License

By contributing to GEOS-ESM projects, you agree your contributions will be
licensed under the [Apache 2.0 License](LICENSE)
